pub struct AnonymousFunctionExpression {
pub comments: CommentGroup,
pub attributes: Vec<AttributeGroupDefinition>,
pub static: Option<Keyword>,
pub function: Keyword,
pub parameters: FunctionLikeParameterListDefinition,
pub use_clause: Option<AnonymousFunctionUseClauseExpression>,
pub return_type: FunctionLikeReturnTypeDefinition,
pub body: BlockStatement,
}Fields
comments: CommentGroupattributes: Vec<AttributeGroupDefinition>static: Option<Keyword>function: Keywordparameters: FunctionLikeParameterListDefinitionuse_clause: Option<AnonymousFunctionUseClauseExpression>return_type: FunctionLikeReturnTypeDefinitionbody: BlockStatementTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for AnonymousFunctionExpression
impl<'__de, __Context> BorrowDecode<'__de, __Context> for AnonymousFunctionExpression
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for AnonymousFunctionExpression
impl Clone for AnonymousFunctionExpression
Sourcefn clone(&self) -> AnonymousFunctionExpression
fn clone(&self) -> AnonymousFunctionExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnonymousFunctionExpression
impl Debug for AnonymousFunctionExpression
Sourceimpl<__Context> Decode<__Context> for AnonymousFunctionExpression
impl<__Context> Decode<__Context> for AnonymousFunctionExpression
Sourceimpl<'de> Deserialize<'de> for AnonymousFunctionExpression
impl<'de> Deserialize<'de> for AnonymousFunctionExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AnonymousFunctionExpression
impl Hash for AnonymousFunctionExpression
Sourceimpl JsonSchema for AnonymousFunctionExpression
impl JsonSchema for AnonymousFunctionExpression
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Node for AnonymousFunctionExpression
impl Node for AnonymousFunctionExpression
Sourcefn comments(&self) -> Option<&CommentGroup>
fn comments(&self) -> Option<&CommentGroup>
The comments associated with the node.
Sourcefn initial_position(&self) -> usize
fn initial_position(&self) -> usize
The position of the first token in the node.
Sourcefn final_position(&self) -> usize
fn final_position(&self) -> usize
The position of the last token in the node, including the last token itself. Read more
Sourcefn get_description(&self) -> String
fn get_description(&self) -> String
The description of the node.
Sourceimpl PartialEq for AnonymousFunctionExpression
impl PartialEq for AnonymousFunctionExpression
Sourcefn eq(&self, other: &AnonymousFunctionExpression) -> bool
fn eq(&self, other: &AnonymousFunctionExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AnonymousFunctionExpression
impl StructuralPartialEq for AnonymousFunctionExpression