pub struct AnonymousFunctionUseClauseExpression {
pub comments: CommentGroup,
pub use: Keyword,
pub left_parenthesis: usize,
pub variables: CommaSeparated<AnonymousFunctionUseClauseVariableExpression>,
pub right_parenthesis: usize,
}Fields
comments: CommentGroupuse: Keywordleft_parenthesis: usizevariables: CommaSeparated<AnonymousFunctionUseClauseVariableExpression>right_parenthesis: usizeTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for AnonymousFunctionUseClauseExpression
impl<'__de, __Context> BorrowDecode<'__de, __Context> for AnonymousFunctionUseClauseExpression
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for AnonymousFunctionUseClauseExpression
impl Clone for AnonymousFunctionUseClauseExpression
Sourcefn clone(&self) -> AnonymousFunctionUseClauseExpression
fn clone(&self) -> AnonymousFunctionUseClauseExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__Context> Decode<__Context> for AnonymousFunctionUseClauseExpression
impl<__Context> Decode<__Context> for AnonymousFunctionUseClauseExpression
Sourceimpl<'de> Deserialize<'de> for AnonymousFunctionUseClauseExpression
impl<'de> Deserialize<'de> for AnonymousFunctionUseClauseExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnonymousFunctionUseClauseExpression
impl JsonSchema for AnonymousFunctionUseClauseExpression
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Node for AnonymousFunctionUseClauseExpression
impl Node for AnonymousFunctionUseClauseExpression
Sourcefn comments(&self) -> Option<&CommentGroup>
fn comments(&self) -> Option<&CommentGroup>
The comments associated with the node.
Sourcefn initial_position(&self) -> usize
fn initial_position(&self) -> usize
The position of the first token in the node.
Sourcefn final_position(&self) -> usize
fn final_position(&self) -> usize
The position of the last token in the node, including the last token itself. Read more
Sourcefn get_description(&self) -> String
fn get_description(&self) -> String
The description of the node.
Sourceimpl PartialEq for AnonymousFunctionUseClauseExpression
impl PartialEq for AnonymousFunctionUseClauseExpression
Sourcefn eq(&self, other: &AnonymousFunctionUseClauseExpression) -> bool
fn eq(&self, other: &AnonymousFunctionUseClauseExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AnonymousFunctionUseClauseExpression
impl StructuralPartialEq for AnonymousFunctionUseClauseExpression